UI Endpoints - Nautobot Documentation

Skip to content

# UI Related API Endpoints

Added in version 2.0.0

Nautobot now retrieves its UI component information from API endpoints.

Important

These UI-related API endpoints serve a very different purpose from the rest. While we encourage users to utilize other API endpoints whenever possilbe in custom development, these API endpoints are not for external users and for internal use only. Therefore, they are not subject to Semantic Versioning and can change at any time to fit Nautobot UI needs until we decide that we are ready to support UI specific endpoints. Note that these API endpoints are hidden from OpenAPI schema as well.